CWL Code of Conduct
===================

The CWL Project is dedicated to providing a harassment-free experience for
everyone. We do not tolerate harassment of participants in any form.

This code of conduct applies to all CWL Project spaces both online and off: the
Google Group, the Gitter chat room, the Google Hangouts chats, and any other
CWL spaces. Anyone who violates this code of conduct may be sanctioned or
expelled from these spaces at the discretion of the CWL Leadership Team.

Some CWL Project spaces may have additional rules in place, which will be
made clearly available to participants. Participants are responsible for
knowing and abiding by these rules.

Harassment includes, but is not limited to:

 - Offensive comments related to gender, gender identity and expression, sexual
orientation, disability, mental illness, neuro(a)typicality, physical
appearance, body size, age, race, or religion.
 - Unwelcome comments regarding a person’s lifestyle choices and practices,
including those related to food, health, parenting, drugs, and employment.
 - Deliberate misgendering or use of [dead](https://www.quora.com/What-is-deadnaming/answer/Nancy-C-Walker)
or rejected names.
 - Gratuitous or off-topic sexual images or behaviour  in spaces where they’re not
appropriate.
 - Physical contact and simulated physical contact (eg, textual descriptions like
“\*hug\*” or “\*backrub\*”) without consent or after a request to stop.
 - Threats of violence.
 - Incitement of violence towards any individual, including encouraging a person
to commit suicide or to engage in self-harm.
 - Deliberate intimidation.
 - Stalking or following.
 - Harassing photography or recording, including logging online activity for
harassment purposes.
 - Sustained disruption of discussion.
 - Unwelcome sexual attention.
 - Pattern of inappropriate social contact, such as requesting/assuming
inappropriate levels of intimacy with others
 - Continued one-on-one communication after requests to cease.
 - Deliberate “outing” of any aspect of a person’s identity without their consent
except as necessary to protect vulnerable people from intentional abuse.
 - Publication of non-harassing private communication.

The CWL Project prioritizes marginalized people’s safety over privileged
people’s comfort. The CWL Leadeship Team will not act on complaints regarding:

 - ‘Reverse’ -isms, including ‘reverse racism,’ ‘reverse sexism,’ and ‘cisphobia’
 - Reasonable communication of boundaries, such as “leave me alone,” “go away,” or
“I’m not discussing this with you.”
 - Communicating in a [tone](http://geekfeminism.wikia.com/wiki/Tone_argument)
you don’t find congenial

Reporting
---------

If you are being harassed by a member of the CWL Project, notice that someone
else is being harassed, or have any other concerns, please contact the CWL
Leadership Team at leadership@commonwl.org. If person who is harassing
you is on the team, they will recuse themselves from handling your incident. We
will respond as promptly as we can.

This code of conduct applies to CWL Project spaces, but if you are being
harassed by a member of CWL Project outside our spaces, we still want to
know about it. We will take all good-faith reports of harassment by CWL Project
members, especially the CWL Leadership Team, seriously. This includes harassment
outside our spaces and harassment that took place at any point in time. The
abuse team reserves the right to exclude people from the CWL Project based on
their past behavior, including behavior outside CWL Project spaces and
behavior towards people who are not in the CWL Project.

In order to protect volunteers from abuse and burnout, we reserve the right to
reject any report we believe to have been made in bad faith. Reports intended
to silence legitimate criticism may be deleted without response.

We will respect confidentiality requests for the purpose of protecting victims
of abuse. At our discretion, we may publicly name a person about whom we’ve
received harassment complaints, or privately warn third parties about them, if
we believe that doing so will increase the safety of CWL Project members or
the general public. We will not name harassment victims without their
affirmative consent.

Consequences
------------

Participants asked to stop any harassing behavior are expected to comply
immediately.

If a participant engages in harassing behavior, the CWL Leadership Team may
take any action they deem appropriate, up to and including expulsion from all
CWL Project spaces and identification of the participant as a harasser to other
CWL Project members or the general public.

This anti-harassment policy is based on the [example policy from the Geek
Feminism wiki](http://geekfeminism.wikia.com/wiki/Community_anti-harassment/Policy),
created by the Geek Feminism community.

CWL Leadership Team
-------------------

As a stop gap measure until a more formal governance structure is adopted, the
following individuals make up the leadership of the CWL Project: Peter Amstutz,
John Chilton, Michael R. Crusoe, and Nebojša Tijanić.

To report an issue with anyone on the team you can escalate to Ward Vandewege
 (Curoverse) ward@curoverse.com, Anton Nekrutenko (Galaxy)
anton AT bx DOT psu DOT edu, C. Titus Brown (UC Davis) ctbrown@ucdavis.edu, or
Brandi Davis-Dusenbery (Seven Bridges Genomics) brandi@sbgenomics.com.
